@@ -20,7 +20,7 @@ project = "Heritrix3 Client"
 year = "2021"
 author = "Erik Körner"
 copyright = "{0}, {1}".format(year, author)
-version = release = "0.2.0"
+version = release = "0.3.0"
 
 pygments_style = "trac"
 templates_path = ["."]
@@ -48,3 +48,8 @@ autodoc_member_order = "bysource"
 napoleon_use_ivar = True
 napoleon_use_rtype = False
 napoleon_use_param = False
+
+linkcheck_ignore = [
+    # local test urls?
+    r"^https://localhost:8443/engine",
+]
